@@ -7,7 +7,7 @@
 #  define GRANTLEE_CORE_NO_EXPORT
 #else
 #  ifndef GRANTLEE_CORE_EXPORT
-#    ifdef GRANTLEE_CORE_MAKEDLL
+#    ifdef grantlee_core_EXPORTS
         /* We are building this library */
 #      define GRANTLEE_CORE_EXPORT __attribute__((visibility("default")))
 #    else
@@ -22,9 +22,23 @@
 #endif
 
 #ifndef GRANTLEE_CORE_DEPRECATED
-#  define GRANTLEE_CORE_DEPRECATED __attribute__ ((__deprecated__)) GRANTLEE_CORE_EXPORT
+#  define GRANTLEE_CORE_DEPRECATED __attribute__ ((__deprecated__))
 #endif
 
-#endif // GRANTLEE_CORE_EXPORT_H
+#ifndef GRANTLEE_CORE_DEPRECATED_EXPORT
+#  define GRANTLEE_CORE_DEPRECATED_EXPORT GRANTLEE_CORE_EXPORT GRANTLEE_CORE_DEPRECATED
+#endif
+
+#ifndef GRANTLEE_CORE_DEPRECATED_NO_EXPORT
+#  define GRANTLEE_CORE_DEPRECATED_NO_EXPORT GRANTLEE_CORE_NO_EXPORT GRANTLEE_CORE_DEPRECATED
+#endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef GRANTLEE_CORE_NO_DEPRECATED
+#    define GRANTLEE_CORE_NO_DEPRECATED
+#  endif
+#endif
+
+#endif
 
 #define GRANTLEE_TESTS_EXPORT GRANTLEE_CORE_EXPORT
